# UPnP for Twisted

`txupnp` is a python2/3 library to interact with UPnP gateways using Twisted

## Installation

```
pip install --upgrade txupnp
```

## Usage

```
usage: txupnp-cli [-h] [--debug_logging] [--include_igd_xml] command

positional arguments:
  command            debug_device | list_mappings | get_external_ip |
                     add_mapping | delete_mapping

optional arguments:
  -h, --help         show this help message and exit
  --debug_logging
  --include_igd_xml
```


## License

This project is MIT licensed. For the full license, see [LICENSE](LICENSE).

## Contact

The primary contact for this project is @jackrobison
